@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: __init__.py 10005 2017-06-03 09:30:38Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (Fri, 25 Sep 2015) $
-# $Revision: 9439 $
+# $Author: David $ (last)
+# $Date: 2017-06-03 17:30:38 +0800 (週六, 03 六月 2017) $
+# $Revision: 10005 $
 #
 # Contributors:
 #  Bear (original author)
@@ -26,6 +26,8 @@ import sys
 import traceback
 import logging
 
+from Iuno.cloud.mail import tasks
+
 logger = logging.getLogger(__name__)
 
 def attachSettings(settingsLocals, backends, preferred, config):
