@@ -92,6 +92,11 @@ class Command(BaseCommand):
         host = temp.render(context)
         content = content.replace('ALLOWED_HOSTS = []', host)
 
+        # install app
+        temp1 = get_template('scaffold/InstalledApps.py').render()
+        temp2 = get_template('scaffold/InstalledAppsTemplate.py').render()
+        content = content.replace(temp1, temp2)
+
         # db & static
         temp = get_template('scaffold/Database.py')
         database = temp.render()
